@@ -1,5 +1,6 @@
 """Top-level package for ape-apeman."""
 
+from .main import wrangler
 from .version import __author__, __email__, __timestamp__, __version__
 
-__all__ = [__version__, __timestamp__, __author__, __email__]
+__all__ = ["wrangler", __version__, __timestamp__, __author__, __email__]
